@@ -9,7 +9,7 @@
 # @Description  : 
 
 from PIL import Image
-from paddleocr import PaddleOCR, draw_ocr
+from paddleocr import draw_ocr
 from appzoo.utils import get_module_path
 
 
